==> jboss-as-threads-7.0.2.Final-sources.jar: org/jboss/as/threads/CommonAttributes.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.threads;

/**
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 * @version $Revision: 1.1 $
 */
public class CommonAttributes {
    public static final String ALLOW_CORE_TIMEOUT = "allow-core-timeout";
    public static final String BLOCKING = "blocking";
    public static final String BOUNDED_QUEUE_THREAD_POOL = "bounded-queue-thread-pool";
    public static final String CORE_THREADS = "core-threads";
    public static final String COUNT = "count";
    public static final String PER_CPU = "per-cpu";
    public static final String HANDOFF_EXECUTOR = "handoff-executor";
    public static final String NAME = "name";
    public static final String GROUP_NAME = "group-name";
    public static final String KEEPALIVE_TIME = "keepalive-time";
    public static final String MAX_THREADS = "max-threads";
    public static final String PRIORITY = "priority";
    public static final String PROPERTIES = "properties";
    public static final String PROPERTY = "property";
    public static final String QUEUELESS_THREAD_POOL = "queueless-thread-pool";
    public static final String QUEUE_LENGTH = "queue-length";
    public static final String SCHEDULED_THREAD_POOL = "scheduled-thread-pool";
    public static final String THREADS = "threads";
    public static final String TIME = "time";
    public static final String THREAD_FACTORY = "thread-factory";
    public static final String THREAD_NAME_PATTERN = "thread-name-pattern";
    public static final String THREAD_POOL = "thread-pool";
    public static final String UNBOUNDED_QUEUE_THREAD_POOL = "unbounded-queue-thread-pool";
    public static final String UNIT = "unit";
    public static final String VALUE = "value";
}

==> jboss-as-threads-7.1.1.Final-sources.jar: org/jboss/as/threads/CommonAttributes.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.threads;

/**
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
public class CommonAttributes {
    public static final String ACTIVE_COUNT = "active-count";
    public static final String ALLOW_CORE_TIMEOUT = "allow-core-timeout";
    public static final String BLOCKING = "blocking";
    public static final String BLOCKING_BOUNDED_QUEUE_THREAD_POOL = "blocking-bounded-queue-thread-pool";
    public static final String BLOCKING_QUEUELESS_THREAD_POOL = "blocking-queueless-thread-pool";
    public static final String BOUNDED_QUEUE_THREAD_POOL = "bounded-queue-thread-pool";
    public static final String COMPLETED_TASK_COUNT = "completed-task-count";
    public static final String CORE_THREADS = "core-threads";
    public static final String COUNT = "count";
    public static final String CURRENT_THREAD_COUNT = "current-thread-count";
    public static final String PER_CPU = "per-cpu";
    public static final String HANDOFF_EXECUTOR = "handoff-executor";
    public static final String LARGEST_THREAD_COUNT = "largest-thread-count";
    public static final String NAME = "name";
    public static final String GROUP_NAME = "group-name";
    public static final String KEEPALIVE_TIME = "keepalive-time";
    public static final String MAX_THREADS = "max-threads";
    public static final String PRIORITY = "priority";
    public static final String PROPERTIES = "properties";
    public static final String PROPERTY = "property";
    public static final String QUEUELESS_THREAD_POOL = "queueless-thread-pool";
    public static final String QUEUE_LENGTH = "queue-length";
    public static final String REJECTED_COUNT = "rejected-count";
    public static final String SCHEDULED_THREAD_POOL = "scheduled-thread-pool";
    public static final String TASK_COUNT = "task-count";
    public static final String THREADS = "threads";
    public static final String TIME = "time";
    public static final String THREAD_FACTORY = "thread-factory";
    public static final String THREAD_NAME_PATTERN = "thread-name-pattern";
    public static final String UNBOUNDED_QUEUE_THREAD_POOL = "unbounded-queue-thread-pool";
    public static final String UNIT = "unit";
    public static final String VALUE = "value";
}
